pub struct Config {Show 23 fields
pub proxy_app: Address,
pub moniker: Moniker,
pub fast_sync: bool,
pub db_backend: DbBackend,
pub db_dir: PathBuf,
pub log_level: LogLevel,
pub log_format: LogFormat,
pub genesis_file: PathBuf,
pub priv_validator_key_file: Option<PathBuf>,
pub priv_validator_state_file: PathBuf,
pub priv_validator_laddr: Option<Address>,
pub node_key_file: PathBuf,
pub abci: AbciMode,
pub filter_peers: bool,
pub rpc: RpcConfig,
pub p2p: P2PConfig,
pub mempool: MempoolConfig,
pub consensus: ConsensusConfig,
pub storage: StorageConfig,
pub tx_index: TxIndexConfig,
pub instrumentation: InstrumentationConfig,
pub statesync: StatesyncConfig,
pub fastsync: FastsyncConfig,
}Expand description
CometBFT config.toml file
Fields
proxy_app: AddressTCP or UNIX socket address of the ABCI application, or the name of an ABCI application compiled in with the CometBFT binary.
moniker: MonikerA custom human readable name for this node
fast_sync: boolIf this node is many blocks behind the tip of the chain, FastSync allows them to catchup quickly by downloading blocks in parallel and verifying their commits
db_backend: DbBackendDatabase backend: goleveldb | cleveldb | boltdb | rocksdb | badgerdb
db_dir: PathBufDatabase directory
log_level: LogLevelOutput level for logging, including package level options
log_format: LogFormatOutput format: ‘plain’ (colored text) or ‘json’
genesis_file: PathBufPath to the JSON file containing the initial validator set and other meta data
priv_validator_key_file: Option<PathBuf>Path to the JSON file containing the private key to use as a validator in the consensus protocol
priv_validator_state_file: PathBufPath to the JSON file containing the last sign state of a validator
priv_validator_laddr: Option<Address>TCP or UNIX socket address for CometBFT to listen on for connections from an external PrivValidator process
node_key_file: PathBufPath to the JSON file containing the private key to use for node authentication in the p2p protocol
abci: AbciModeMechanism to connect to the ABCI application: socket | grpc
filter_peers: boolIf true, query the ABCI app on connecting to a new peer
so the app can decide if we should keep the connection or not
rpc: RpcConfigrpc server configuration options
p2p: P2PConfigpeer to peer configuration options
mempool: MempoolConfigmempool configuration options
consensus: ConsensusConfigconsensus configuration options
storage: StorageConfigStorage configuration options. This section was only first made available in Tendermint Core v0.34.21.
tx_index: TxIndexConfigtransactions indexer configuration options
instrumentation: InstrumentationConfiginstrumentation configuration options
statesync: StatesyncConfigstatesync configuration options
fastsync: FastsyncConfigfastsync configuration options
Implementations
Sourceimpl Config
impl Config
Sourcepub fn parse_toml<T: AsRef<str>>(toml_string: T) -> Result<Self, Error>
pub fn parse_toml<T: AsRef<str>>(toml_string: T) -> Result<Self, Error>
Parse CometBFT config.toml
Sourcepub fn load_toml_file<P>(path: &P) -> Result<Self, Error>
pub fn load_toml_file<P>(path: &P) -> Result<Self, Error>
Load config.toml from a file